You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tapestry.apache.org by hl...@apache.org on 2008/05/20 20:52:29 UTC

svn commit: r658390 [14/32] - in /tapestry/tapestry5/branches/hlship-20080520: ./ quickstart/src/main/resources/META-INF/ quickstart/src/main/resources/archetype-resources/src/main/java/pages/ quickstart/src/main/resources/archetype-resources/src/main/...

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TapestryModule.java Tue May 20 11:51:35 2008
@@ -12,39 +12,39 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.*;
-import org.apache.tapestry.annotation.*;
-import org.apache.tapestry.beaneditor.Validate;
-import org.apache.tapestry.corelib.data.BlankOption;
-import org.apache.tapestry.corelib.data.GridPagerPosition;
-import org.apache.tapestry.corelib.data.InsertPosition;
-import org.apache.tapestry.grid.GridDataSource;
-import org.apache.tapestry.internal.*;
-import org.apache.tapestry.internal.beaneditor.PrimitiveFieldConstraintGenerator;
-import org.apache.tapestry.internal.beaneditor.ValidateAnnotationConstraintGenerator;
-import org.apache.tapestry.internal.bindings.*;
-import org.apache.tapestry.internal.events.InvalidationListener;
-import org.apache.tapestry.internal.grid.CollectionGridDataSource;
-import org.apache.tapestry.internal.grid.NullDataSource;
-import org.apache.tapestry.internal.renderers.*;
-import org.apache.tapestry.internal.services.*;
-import org.apache.tapestry.internal.transform.*;
-import org.apache.tapestry.internal.translator.*;
-import org.apache.tapestry.internal.util.IntegerRange;
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.annotation.*;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.IdAllocator;
-import org.apache.tapestry.ioc.services.*;
-import org.apache.tapestry.ioc.util.StrategyRegistry;
-import org.apache.tapestry.ioc.util.TimeInterval;
-import org.apache.tapestry.runtime.Component;
-import org.apache.tapestry.runtime.ComponentResourcesAware;
-import org.apache.tapestry.runtime.RenderCommand;
-import org.apache.tapestry.util.StringToEnumCoercion;
-import org.apache.tapestry.validator.*;
+import org.apache.tapestry5.*;
+import org.apache.tapestry5.annotations.*;
+import org.apache.tapestry5.beaneditor.Validate;
+import org.apache.tapestry5.corelib.data.BlankOption;
+import org.apache.tapestry5.corelib.data.GridPagerPosition;
+import org.apache.tapestry5.corelib.data.InsertPosition;
+import org.apache.tapestry5.grid.GridDataSource;
+import org.apache.tapestry5.internal.*;
+import org.apache.tapestry5.internal.beaneditor.PrimitiveFieldConstraintGenerator;
+import org.apache.tapestry5.internal.beaneditor.ValidateAnnotationConstraintGenerator;
+import org.apache.tapestry5.internal.bindings.*;
+import org.apache.tapestry5.internal.events.InvalidationListener;
+import org.apache.tapestry5.internal.grid.CollectionGridDataSource;
+import org.apache.tapestry5.internal.grid.NullDataSource;
+import org.apache.tapestry5.internal.renderers.*;
+import org.apache.tapestry5.internal.services.*;
+import org.apache.tapestry5.internal.transform.*;
+import org.apache.tapestry5.internal.translator.*;
+import org.apache.tapestry5.internal.util.IntegerRange;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.annotations.*;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.IdAllocator;
+import org.apache.tapestry5.ioc.services.*;
+import org.apache.tapestry5.ioc.util.StrategyRegistry;
+import org.apache.tapestry5.ioc.util.TimeInterval;
+import org.apache.tapestry5.runtime.Component;
+import org.apache.tapestry5.runtime.ComponentResourcesAware;
+import org.apache.tapestry5.runtime.RenderCommand;
+import org.apache.tapestry5.util.StringToEnumCoercion;
+import org.apache.tapestry5.validator.*;
 import org.apache.tapestry5.json.JSONObject;
 import org.apache.tapestry5.services.*;
 import org.slf4j.Logger;
@@ -260,7 +260,7 @@
         // For scriptaculous, etc., this version is not the version of the library, but the version
         // bundled with Tapestry.
 
-        configuration.add("tapestry/" + version, "org/apache/tapestry");
+        configuration.add("tapestry/" + version, "org/apache/tapestry5");
 
         configuration.add("scriptaculous/" + version, scriptaculousPath);
 
@@ -269,36 +269,36 @@
 
     public static void contributeComponentClassResolver(Configuration<LibraryMapping> configuration)
     {
-        configuration.add(new LibraryMapping("core", "org.apache.tapestry.corelib"));
+        configuration.add(new LibraryMapping("core", "org.apache.tapestry5.corelib"));
     }
 
     /**
      * Adds a number of standard component class transform workers: <dl> <dt>Retain </dt> <dd>Allows fields to retain
      * their values between requests</dd> <dt>Persist </dt> <dd>Allows fields to store their their value persistently
      * between requests</dd> <dt>Parameter </dt> <dd>Identifies parameters based on the {@link
-     * org.apache.tapestry.annotation.Parameter} annotation</dd> <dt>Component </dt> <dd>Defines embedded components
-     * based on the {@link org.apache.tapestry.annotation.Component} annotation</dd> <dt>Mixin </dt> <dd>Adds a mixin as
+     * org.apache.tapestry5.annotations.Parameter} annotation</dd> <dt>Component </dt> <dd>Defines embedded components
+     * based on the {@link org.apache.tapestry5.annotations.Component} annotation</dd> <dt>Mixin </dt> <dd>Adds a mixin as
      * part of a component's implementation</dd> <dt>Environment </dt> <dd>Allows fields to contain values extracted
-     * from the {@link org.apache.tapestry.services.Environment} service</dd> <dt>Inject </dt> <dd>Used with the {@link
-     * org.apache.tapestry.ioc.annotation.Inject} annotation, when a value is supplied</dd> <dt>InjectPage</dt> <dd>Adds
-     * code to allow access to other pages via the {@link org.apache.tapestry.annotation.InjectPage} field
+     * from the {@link org.apache.tapestry5.services.Environment} service</dd> <dt>Inject </dt> <dd>Used with the {@link
+     * org.apache.tapestry5.ioc.annotations.Inject} annotation, when a value is supplied</dd> <dt>InjectPage</dt> <dd>Adds
+     * code to allow access to other pages via the {@link org.apache.tapestry5.annotations.InjectPage} field
      * annotation</dd> <dt>InjectBlock </dt> <dd>Allows a block from the template to be injected into a field</dd>
-     * <dt>IncludeStylesheet </dt> <dd>Supports the {@link org.apache.tapestry.annotation.IncludeStylesheet}
-     * annotation</dd> <dt>IncludeJavaScriptLibrary </dt> <dd>Supports the {@link org.apache.tapestry.annotation.IncludeJavaScriptLibrary}
+     * <dt>IncludeStylesheet </dt> <dd>Supports the {@link org.apache.tapestry5.annotations.IncludeStylesheet}
+     * annotation</dd> <dt>IncludeJavaScriptLibrary </dt> <dd>Supports the {@link org.apache.tapestry5.annotations.IncludeJavaScriptLibrary}
      * annotation</dd> <dt>SupportsInformalParameters </dt> <dd>Checks for the annotation</dd> <dt>Meta </dt> <dd>Checks
      * for meta data and adds it to the component model</dd> <dt>ApplicationState </dt> <dd>Converts fields that
      * reference application state objects <dt>UnclaimedField </dt> <dd>Identifies unclaimed fields and resets them to
      * null/0/false at the end of the request</dd> <dt>RenderCommand </dt> <dd>Ensures all components also implement
-     * {@link org.apache.tapestry.runtime.RenderCommand}</dd> <dt>SetupRender, BeginRender, etc. </dt> <dd>Correspond to
+     * {@link org.apache.tapestry5.runtime.RenderCommand}</dd> <dt>SetupRender, BeginRender, etc. </dt> <dd>Correspond to
      * component render phases and annotations</dd> <dt>InvokePostRenderCleanupOnResources </dt> <dd>Makes sure {@link
-     * org.apache.tapestry.internal.InternalComponentResources#postRenderCleanup()} is invoked after a component
-     * finishes rendering</dd> <dt>Secure</dt> <dd>Checks for the {@link org.apache.tapestry.annotation.Secure}
-     * annotation</dd> <dt>ContentType</dt> <dd>Checks for {@link org.apache.tapestry.annotation.ContentType}
-     * annotation</dd> <dt>ResponseEncoding</dt> <dd>Checks for the {@link org.apache.tapestry.annotation.ResponseEncoding}
+     * org.apache.tapestry5.internal.InternalComponentResources#postRenderCleanup()} is invoked after a component
+     * finishes rendering</dd> <dt>Secure</dt> <dd>Checks for the {@link org.apache.tapestry5.annotations.Secure}
+     * annotation</dd> <dt>ContentType</dt> <dd>Checks for {@link org.apache.tapestry5.annotations.ContentType}
+     * annotation</dd> <dt>ResponseEncoding</dt> <dd>Checks for the {@link org.apache.tapestry5.annotations.ResponseEncoding}
      * annotation</dd> <dt>GenerateAccessors</dt> <dd>Generates accessor methods if {@link
-     * org.apache.tapestry.annotation.Property} annotation is present </dd> <dt>Cached</dt> <dd>Checks for the {@link
-     * org.apache.tapestry.annotation.Cached} annotation</dd><dt>Log</dt> <dd>Checks for the {@link
-     * org.apache.tapestry.annotation.Log} annotation</dd></dl>
+     * org.apache.tapestry5.annotations.Property} annotation is present </dd> <dt>Cached</dt> <dd>Checks for the {@link
+     * org.apache.tapestry5.annotations.Cached} annotation</dd><dt>Log</dt> <dd>Checks for the {@link
+     * org.apache.tapestry5.annotations.Log} annotation</dd></dl>
      */
     public static void contributeComponentClassTransformWorker(
             OrderedConfiguration<ComponentClassTransformWorker> configuration,
@@ -386,9 +386,9 @@
     }
 
     /**
-     * <dl> <dt>Annotation</dt> <dd>Checks for {@link org.apache.tapestry.beaneditor.DataType} annotation</dd>
-     * <dt>Default  (ordered last)</dt> <dd>{@link org.apache.tapestry.internal.services.DefaultDataTypeAnalyzer}
-     * service ({@link #contributeDefaultDataTypeAnalyzer(org.apache.tapestry.ioc.MappedConfiguration)} })</dd> </dl>
+     * <dl> <dt>Annotation</dt> <dd>Checks for {@link org.apache.tapestry5.beaneditor.DataType} annotation</dd>
+     * <dt>Default  (ordered last)</dt> <dd>{@link org.apache.tapestry5.internal.services.DefaultDataTypeAnalyzer}
+     * service ({@link #contributeDefaultDataTypeAnalyzer(org.apache.tapestry5.ioc.MappedConfiguration)} })</dd> </dl>
      */
     public static void contributeDataTypeAnalyzer(OrderedConfiguration<DataTypeAnalyzer> configuration,
                                                   @InjectService("DefaultDataTypeAnalyzer")
@@ -556,8 +556,8 @@
      * Continues a number of filters into the RequestHandler service: <dl> <dt>StaticFiles</dt> <dd>Checks to see if the
      * request is for an actual file, if so, returns true to let the servlet container process the request</dd>
      * <dt>CheckForUpdates</dt> <dd>Periodically fires events that checks to see if the file system sources for any
-     * cached data has changed (see {@link org.apache.tapestry.internal.services.CheckForUpdatesFilter}).
-     * <dt>ErrorFilter</dt> <dd>Catches request errors and lets the {@link org.apache.tapestry.services.RequestExceptionHandler}
+     * cached data has changed (see {@link org.apache.tapestry5.internal.services.CheckForUpdatesFilter}).
+     * <dt>ErrorFilter</dt> <dd>Catches request errors and lets the {@link org.apache.tapestry5.services.RequestExceptionHandler}
      * handle them</dd> <dt>Localization</dt> <dd>Determines the locale for the current request from header data or
      * cookies in the request</dd> <dt>StoreIntoGlobals</dt> <dd>Stores the request and response into the {@link
      * org.apache.tapestry5.services.RequestGlobals} service (this is repeated at the end of the pipeline, in case any
@@ -618,12 +618,12 @@
     }
 
     /**
-     * Adds coercions: <ul> <li>String to {@link org.apache.tapestry.SelectModel} <li>String to {@link
-     * org.apache.tapestry.corelib.data.InsertPosition} <li>Map to {@link org.apache.tapestry.SelectModel}
-     * <li>Collection to {@link GridDataSource} <li>null to {@link org.apache.tapestry.grid.GridDataSource} <li>String
-     * to {@link org.apache.tapestry.corelib.data.GridPagerPosition} <li>List to {@link org.apache.tapestry.SelectModel}
-     * <li>{@link org.apache.tapestry.runtime.ComponentResourcesAware} (typically, a component) to {@link
-     * org.apache.tapestry.ComponentResources} <li>String to {@link org.apache.tapestry.corelib.data.BlankOption} </ul>
+     * Adds coercions: <ul> <li>String to {@link org.apache.tapestry5.SelectModel} <li>String to {@link
+     * org.apache.tapestry5.corelib.data.InsertPosition} <li>Map to {@link org.apache.tapestry5.SelectModel}
+     * <li>Collection to {@link GridDataSource} <li>null to {@link org.apache.tapestry5.grid.GridDataSource} <li>String
+     * to {@link org.apache.tapestry5.corelib.data.GridPagerPosition} <li>List to {@link org.apache.tapestry5.SelectModel}
+     * <li>{@link org.apache.tapestry5.runtime.ComponentResourcesAware} (typically, a component) to {@link
+     * org.apache.tapestry5.ComponentResources} <li>String to {@link org.apache.tapestry5.corelib.data.BlankOption} </ul>
      */
     public static void contributeTypeCoercer(Configuration<CoercionTuple> configuration)
     {
@@ -797,7 +797,7 @@
 
     /**
      * Builds the source of {@link Messages} containing validation messages. The contributions are paths to message
-     * bundles (resource paths within the classpath); the default contribution is "org/apache/tapestry/internal/ValidationMessages".
+     * bundles (resource paths within the classpath); the default contribution is "org/apache/tapestry5/internal/ValidationMessages".
      */
     public ValidationMessagesSource buildValidationMessagesSource(Collection<String> configuration,
 
@@ -831,7 +831,7 @@
     }
 
     /**
-     * Builds a proxy to the current {@link org.apache.tapestry.RenderSupport} inside this thread's {@link
+     * Builds a proxy to the current {@link org.apache.tapestry5.RenderSupport} inside this thread's {@link
      * Environment}.
      */
     public RenderSupport buildRenderSupport()
@@ -840,8 +840,8 @@
     }
 
     /**
-     * Builds a proxy to the current {@link org.apache.tapestry.services.FormSupport} inside this thread's {@link
-     * org.apache.tapestry.services.Environment}.
+     * Builds a proxy to the current {@link org.apache.tapestry5.services.FormSupport} inside this thread's {@link
+     * org.apache.tapestry5.services.Environment}.
      */
     public FormSupport buildFormSupport()
     {
@@ -858,9 +858,9 @@
     }
 
     /**
-     * Analyzes properties to determine the data types, used to {@linkplain #contributeBeanBlockSource(org.apache.tapestry.ioc.Configuration)}
+     * Analyzes properties to determine the data types, used to {@linkplain #contributeBeanBlockSource(org.apache.tapestry5.ioc.Configuration)}
      * locale display and edit blocks} for properties.  The default behaviors look for a {@link
-     * org.apache.tapestry.beaneditor.DataType} annotation before deriving the data type from the property type.
+     * org.apache.tapestry5.beaneditor.DataType} annotation before deriving the data type from the property type.
      */
     @Marker(Primary.class)
     public DataTypeAnalyzer buildDataTypeAnalyzer(List<DataTypeAnalyzer> configuration)
@@ -1049,7 +1049,7 @@
     }
 
     /**
-     * Returns a {@link org.apache.tapestry.ioc.services.ClassFactory} that can be used to create extra classes around
+     * Returns a {@link org.apache.tapestry5.ioc.services.ClassFactory} that can be used to create extra classes around
      * component classes. This ClassFactory will be cleared whenever an underlying component class is discovered to have
      * changed. Use of this class factory implies that your code will become aware of this (if necessary) to discard any
      * cached object (alas, this currently involves dipping into the internals side to register for the correct
@@ -1110,14 +1110,14 @@
 
     /**
      * The MarkupRenderer service is used to render a full page as markup.  Supports an ordered configuration of {@link
-     * org.apache.tapestry.services.MarkupRendererFilter}s.
+     * org.apache.tapestry5.services.MarkupRendererFilter}s.
      *
      * @param pageRenderQueue handles the bulk of the work
      * @param logger          used to log errors building the pipeline
      * @param configuration   filters on this service
      * @return the service
-     * @see #contributeMarkupRenderer(org.apache.tapestry.ioc.OrderedConfiguration, org.apache.tapestry.Asset,
-     *      org.apache.tapestry.Asset, ValidationMessagesSource, org.apache.tapestry.ioc.services.SymbolSource,
+     * @see #contributeMarkupRenderer(org.apache.tapestry5.ioc.OrderedConfiguration, org.apache.tapestry5.Asset,
+     *      org.apache.tapestry5.Asset, ValidationMessagesSource, org.apache.tapestry5.ioc.services.SymbolSource,
      *      AssetSource)
      */
     public MarkupRenderer buildMarkupRenderer(final PageRenderQueue pageRenderQueue, Logger logger,
@@ -1136,15 +1136,15 @@
     }
 
     /**
-     * A wrapper around {@link org.apache.tapestry.internal.services.PageRenderQueue} used for partial page renders.
-     * Supports an ordered configuration of {@link org.apache.tapestry.services.PartialMarkupRendererFilter}s.
+     * A wrapper around {@link org.apache.tapestry5.internal.services.PageRenderQueue} used for partial page renders.
+     * Supports an ordered configuration of {@link org.apache.tapestry5.services.PartialMarkupRendererFilter}s.
      *
      * @param logger        used to log warnings creating the pipeline
      * @param configuration filters for the service
      * @param renderQueue   does most of the work
      * @return the service
-     * @see #contributePartialMarkupRenderer(org.apache.tapestry.ioc.OrderedConfiguration, org.apache.tapestry.Asset,
-     *      org.apache.tapestry.ioc.services.SymbolSource, AssetSource, ValidationMessagesSource)
+     * @see #contributePartialMarkupRenderer(org.apache.tapestry5.ioc.OrderedConfiguration, org.apache.tapestry5.Asset,
+     *      org.apache.tapestry5.ioc.services.SymbolSource, AssetSource, ValidationMessagesSource)
      */
     public PartialMarkupRenderer buildPartialMarkupRenderer(Logger logger,
                                                             List<PartialMarkupRendererFilter> configuration,
@@ -1175,7 +1175,7 @@
      * Builds the component action request handler for traditional (non-Ajax) requests. These typically result in a
      * redirect to a Tapestry render URL.
      *
-     * @see org.apache.tapestry.internal.services.ComponentEventRequestHandlerImpl
+     * @see org.apache.tapestry5.internal.services.ComponentEventRequestHandlerImpl
      */
     @Marker(Traditional.class)
     public ComponentEventRequestHandler buildComponentEventRequestHandler(
@@ -1186,7 +1186,7 @@
     }
 
     /**
-     * Builds the action request handler for Ajax requests, based on {@link org.apache.tapestry.internal.services.AjaxComponentEventRequestHandler}.
+     * Builds the action request handler for Ajax requests, based on {@link org.apache.tapestry5.internal.services.AjaxComponentEventRequestHandler}.
      * Filters on the request handler are supported here as well.
      */
     @Marker(Ajax.class)
@@ -1229,7 +1229,7 @@
      * render link)</dd> <dt>String</dt> <dd>Sends a page render redirect</dd> <dt>Class</dt> <dd>Interpreted as the
      * class name of a page, sends a page render render redirect (this is more refactoring safe than the page name)</dd>
      * <dt>{@link Component}</dt> <dd>A page's root component (though a non-root component will work, but will generate
-     * a warning). A direct to the containing page is sent.</dd> <dt>{@link org.apache.tapestry.StreamResponse}</dt>
+     * a warning). A direct to the containing page is sent.</dd> <dt>{@link org.apache.tapestry5.StreamResponse}</dt>
      * <dd>The stream response is sent as the actual reply.</dd> <dt>URL</dt> <dd>Sends a redirect to a (presumably)
      * external URL</dd> </dl>
      */
@@ -1273,10 +1273,10 @@
 
     /**
      * Contributes handlers for the following types: <dl> <dt>Object</dt> <dd>Failure case, added to provide more useful
-     * exception message</dd> <dt>{@link RenderCommand}</dt> <dd>Typically, a {@link org.apache.tapestry.Block}</dd>
+     * exception message</dd> <dt>{@link RenderCommand}</dt> <dd>Typically, a {@link org.apache.tapestry5.Block}</dd>
      * <dt>{@link Component}</dt> <dd>Renders the component and its body</dd> <dt>{@link
      * org.apache.tapestry5.json.JSONObject}</dt> <dd>The JSONObject is returned as a text/javascript response</dd>
-     * <dt>{@link org.apache.tapestry.StreamResponse}</dt> <dd>The stream response is sent as the actual response</dd>
+     * <dt>{@link org.apache.tapestry5.StreamResponse}</dt> <dd>The stream response is sent as the actual response</dd>
      * </dl>
      */
 
@@ -1293,7 +1293,7 @@
      * The MasterDispatcher is a chain-of-command of individual Dispatchers, each handling (like a servlet) a particular
      * kind of incoming request. <dl> <dt>RootPath</dt> <dd>Renders the start page for the "/" request</dd>
      * <dt>Asset</dt> <dd>Provides access to classpath assets</dd> <dt>PageRender</dt> <dd>Identifies the {@link
-     * org.apache.tapestry.services.PageRenderRequestParameters} and forwards onto {@link PageRenderRequestHandler}</dd>
+     * org.apache.tapestry5.services.PageRenderRequestParameters} and forwards onto {@link PageRenderRequestHandler}</dd>
      * <dt>ComponentEvent</dt> <dd>Identifies the {@link ComponentEventRequestParameters} and forwards onto the {@link
      * ComponentEventRequestHandler}</dd> </dl>
      */
@@ -1323,8 +1323,8 @@
 
     /**
      * Contributes a default object renderer for type Object, plus specialized renderers for {@link
-     * org.apache.tapestry.services.Request}, {@link org.apache.tapestry.ioc.Location}, {@link
-     * org.apache.tapestry.ComponentResources}, {@link org.apache.tapestry.EventContext}, List, and Object[].
+     * org.apache.tapestry5.services.Request}, {@link org.apache.tapestry5.ioc.Location}, {@link
+     * org.apache.tapestry5.ComponentResources}, {@link org.apache.tapestry5.EventContext}, List, and Object[].
      */
     public void contributeObjectRenderer(MappedConfiguration<Class, ObjectRenderer> configuration,
 
@@ -1367,13 +1367,13 @@
 
 
     /**
-     * Adds page render filters, each of which provides an {@link org.apache.tapestry.annotation.Environmental} service.
+     * Adds page render filters, each of which provides an {@link org.apache.tapestry5.annotations.Environmental} service.
      * Filters often provide {@link Environmental} services needed by components as they render. <dl>
-     * <dt>PageRenderSupport</dt>  <dd>Provides {@link org.apache.tapestry.RenderSupport}</dd>
-     * <dt>ClientBehaviorSupport</dt> <dd>Provides {@link org.apache.tapestry.internal.services.ClientBehaviorSupport}</dd>
-     * <dt>Heartbeat</dt> <dd>Provides {@link org.apache.tapestry.services.Heartbeat}</dd>
-     * <dt>DefaultValidationDecorator</dt> <dd>Provides {@link org.apache.tapestry.ValidationDecorator} (as an instance
-     * of {@link org.apache.tapestry.internal.DefaultValidationDecorator})</dd> </dl>
+     * <dt>PageRenderSupport</dt>  <dd>Provides {@link org.apache.tapestry5.RenderSupport}</dd>
+     * <dt>ClientBehaviorSupport</dt> <dd>Provides {@link org.apache.tapestry5.internal.services.ClientBehaviorSupport}</dd>
+     * <dt>Heartbeat</dt> <dd>Provides {@link org.apache.tapestry5.services.Heartbeat}</dd>
+     * <dt>DefaultValidationDecorator</dt> <dd>Provides {@link org.apache.tapestry5.ValidationDecorator} (as an instance
+     * of {@link org.apache.tapestry5.internal.DefaultValidationDecorator})</dd> </dl>
      */
     public void contributeMarkupRenderer(OrderedConfiguration<MarkupRendererFilter> configuration,
 
@@ -1408,7 +1408,7 @@
 
                                                                   // Uses functions defined by the prior three
 
-                                                                  "org/apache/tapestry/tapestry.js");
+                                                                  "org/apache/tapestry5/tapestry.js");
 
                 support.addStylesheetLink(stylesheetAsset, null);
 
@@ -1487,13 +1487,13 @@
 
     /**
      * Contributes {@link PartialMarkupRendererFilter}s used when rendering a partial Ajax response.  This is an analog
-     * to {@link #contributeMarkupRenderer(org.apache.tapestry.ioc.OrderedConfiguration, org.apache.tapestry.Asset,
-     * org.apache.tapestry.Asset, ValidationMessagesSource, org.apache.tapestry.ioc.services.SymbolSource, AssetSource)}
+     * to {@link #contributeMarkupRenderer(org.apache.tapestry5.ioc.OrderedConfiguration, org.apache.tapestry5.Asset,
+     * org.apache.tapestry5.Asset, ValidationMessagesSource, org.apache.tapestry5.ioc.services.SymbolSource, AssetSource)}
      * } and overlaps it to some degree. <dl> <dt>   PageRenderSupport     </dt> <dd>Provides {@link
-     * org.apache.tapestry.RenderSupport}</dd> <dt>ClientBehaviorSupport</dt> <dd>Provides {@link
-     * org.apache.tapestry.internal.services.ClientBehaviorSupport}</dd> <dt>Heartbeat</dt> <dd>Provides {@link
-     * org.apache.tapestry.services.Heartbeat}</dd> <dt>DefaultValidationDecorator</dt> <dd>Provides {@link
-     * org.apache.tapestry.ValidationDecorator} (as an instance of {@link org.apache.tapestry.internal.DefaultValidationDecorator})</dd>
+     * org.apache.tapestry5.RenderSupport}</dd> <dt>ClientBehaviorSupport</dt> <dd>Provides {@link
+     * org.apache.tapestry5.internal.services.ClientBehaviorSupport}</dd> <dt>Heartbeat</dt> <dd>Provides {@link
+     * org.apache.tapestry5.services.Heartbeat}</dd> <dt>DefaultValidationDecorator</dt> <dd>Provides {@link
+     * org.apache.tapestry5.ValidationDecorator} (as an instance of {@link org.apache.tapestry5.internal.DefaultValidationDecorator})</dd>
      * </dl>
      */
     public void contributePartialMarkupRenderer(OrderedConfiguration<PartialMarkupRendererFilter> configuration,
@@ -1632,7 +1632,7 @@
 
     public void contributeValidationMessagesSource(Configuration<String> configuration)
     {
-        configuration.add("org/apache/tapestry/internal/ValidationMessages");
+        configuration.add("org/apache/tapestry5/internal/ValidationMessages");
     }
 
     public ValueEncoderSource buildValueEncoderSource(Map<Class, ValueEncoderFactory> configuration)
@@ -1742,8 +1742,8 @@
 
         configuration.add("tapestry.start-page-name", "start");
 
-        configuration.add("tapestry.default-stylesheet", "org/apache/tapestry/default.css");
-        configuration.add("tapestry.field-error-marker", "org/apache/tapestry/field-error-marker.gif");
+        configuration.add("tapestry.default-stylesheet", "org/apache/tapestry5/default.css");
+        configuration.add("tapestry.field-error-marker", "org/apache/tapestry5/field-error-marker.gif");
 
         configuration.add("tapestry.page-pool.soft-limit", "5");
         configuration.add("tapestry.page-pool.soft-wait", "10 ms");
@@ -1768,11 +1768,11 @@
         // contribution based on the path.
 
         configuration.add("tapestry.scriptaculous", "classpath:${tapestry.scriptaculous.path}");
-        configuration.add("tapestry.scriptaculous.path", "org/apache/tapestry/scriptaculous_1_8");
+        configuration.add("tapestry.scriptaculous.path", "org/apache/tapestry5/scriptaculous_1_8");
 
         // Likewise for WebFX DatePicker, currently version 1.0.6
 
-        configuration.add("tapestry.datepicker.path", "org/apache/tapestry/datepicker_106");
+        configuration.add("tapestry.datepicker.path", "org/apache/tapestry5/datepicker_106");
         configuration.add("tapestry.datepicker", "classpath:${tapestry.datepicker.path}");
 
         configuration.add(PersistentFieldManagerImpl.META_KEY, PersistentFieldManagerImpl.DEFAULT_STRATEGY);
@@ -1794,7 +1794,7 @@
     }
 
     /**
-     * Adds a listener to the {@link org.apache.tapestry.internal.services.ComponentInstantiatorSource} that clears the
+     * Adds a listener to the {@link org.apache.tapestry5.internal.services.ComponentInstantiatorSource} that clears the
      * {@link PropertyAccess} and {@link TypeCoercer} caches on a class loader invalidation.  In addition, forces the
      * realization of {@link ComponentClassResolver} at startup.
      */
@@ -1970,7 +1970,7 @@
     /**
      * Contributes filters: <dl> <dt>Ajax</dt> <dd>Determines if the request is Ajax oriented, and redirects to an
      * alternative handler if so</dd> <dt>ImmediateRender</dt> <dd>When {@linkplain
-     * org.apache.tapestry.SymbolConstants#SUPPRESS_REDIRECT_FROM_ACTION_REQUESTS immediate action response rendering}
+     * org.apache.tapestry5.SymbolConstants#SUPPRESS_REDIRECT_FROM_ACTION_REQUESTS immediate action response rendering}
      * is enabled, generates the markup response (instead of a page redirect response, which is the normal behavior)
      * </dd> <dt>Secure</dt> <dd>Sends a redirect if an non-secure request accesses a secure page</dd></dl>
      */

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Traditional.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Traditional.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Traditional.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/Traditional.java Tue May 20 11:51:35 2008
@@ -12,7 +12,7 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
 import java.lang.annotation.*;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformConstants.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformConstants.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformMethodSignature.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformMethodSignature.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import static org.apache.tapestry.ioc.internal.util.Defense.notBlank;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notBlank;
 
 import java.lang.reflect.Modifier;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformUtils.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformUtils.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformUtils.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformUtils.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newMap;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newMap;
 
 import java.util.Map;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TranslatorSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TranslatorSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationMessagesSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationMessagesSource.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ioc.Messages;
+import org.apache.tapestry5.ioc.Messages;
 
 import java.util.Locale;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderFactory.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderFactory.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderFactory.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderFactory.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ValueEncoder;
+import org.apache.tapestry5.ValueEncoder;
 
 /**
  * A source for {@link ValueEncoder} instances of a given type.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValueEncoderSource.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.ValueEncoder;
+import org.apache.tapestry5.ValueEncoder;
 
 /**
  * A source for value encoders based on a property type.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/PageTester.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/PageTester.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/PageTester.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/PageTester.java Tue May 20 11:51:35 2008
@@ -12,22 +12,22 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.test;
+package org.apache.tapestry5.test;
 
-import org.apache.tapestry.dom.Document;
-import org.apache.tapestry.dom.Element;
-import org.apache.tapestry.dom.Node;
-import org.apache.tapestry.internal.InternalConstants;
-import org.apache.tapestry.internal.SingleKeySymbolProvider;
-import org.apache.tapestry.internal.TapestryAppInitializer;
-import org.apache.tapestry.internal.services.*;
-import org.apache.tapestry.internal.test.*;
-import org.apache.tapestry.ioc.Registry;
-import org.apache.tapestry.ioc.def.ModuleDef;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newMap;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import org.apache.tapestry.ioc.services.SymbolProvider;
-import org.apache.tapestry.ioc.util.StrategyRegistry;
+import org.apache.tapestry5.dom.Document;
+import org.apache.tapestry5.dom.Element;
+import org.apache.tapestry5.dom.Node;
+import org.apache.tapestry5.internal.InternalConstants;
+import org.apache.tapestry5.internal.SingleKeySymbolProvider;
+import org.apache.tapestry5.internal.TapestryAppInitializer;
+import org.apache.tapestry5.internal.services.*;
+import org.apache.tapestry5.internal.test.*;
+import org.apache.tapestry5.ioc.Registry;
+import org.apache.tapestry5.ioc.def.ModuleDef;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newMap;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.ioc.services.SymbolProvider;
+import org.apache.tapestry5.ioc.util.StrategyRegistry;
 import org.apache.tapestry5.services.ApplicationGlobals;
 
 import java.util.Locale;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/TapestryTestCase.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/TapestryTestCase.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/TapestryTestCase.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/test/TapestryTestCase.java Tue May 20 11:51:35 2008
@@ -12,29 +12,29 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.test;
+package org.apache.tapestry5.test;
 
-import org.apache.tapestry.*;
-import org.apache.tapestry.annotation.Id;
-import org.apache.tapestry.annotation.Parameter;
-import org.apache.tapestry.annotation.Path;
-import org.apache.tapestry.beaneditor.BeanModel;
-import org.apache.tapestry.beaneditor.PropertyModel;
-import org.apache.tapestry.internal.services.MapMessages;
-import org.apache.tapestry.internal.services.MarkupWriterImpl;
-import static org.apache.tapestry.internal.test.CodeEq.codeEq;
-import org.apache.tapestry.ioc.*;
-import org.apache.tapestry.ioc.annotation.Inject;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import static org.apache.tapestry.ioc.internal.util.CollectionFactory.newList;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.test.IOCTestCase;
-import org.apache.tapestry.model.ComponentModel;
-import org.apache.tapestry.model.EmbeddedComponentModel;
-import org.apache.tapestry.model.MutableComponentModel;
-import org.apache.tapestry.model.ParameterModel;
-import org.apache.tapestry.runtime.Component;
-import org.apache.tapestry.services.*;
+import org.apache.tapestry5.*;
+import org.apache.tapestry5.annotations.Id;
+import org.apache.tapestry5.annotations.Parameter;
+import org.apache.tapestry5.annotations.Path;
+import org.apache.tapestry5.beaneditor.BeanModel;
+import org.apache.tapestry5.beaneditor.PropertyModel;
+import org.apache.tapestry5.internal.services.MapMessages;
+import org.apache.tapestry5.internal.services.MarkupWriterImpl;
+import static org.apache.tapestry5.internal.test.CodeEq.codeEq;
+import org.apache.tapestry5.ioc.*;
+import org.apache.tapestry5.ioc.annotations.Inject;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import static org.apache.tapestry5.ioc.internal.util.CollectionFactory.newList;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.test.IOCTestCase;
+import org.apache.tapestry5.model.ComponentModel;
+import org.apache.tapestry5.model.EmbeddedComponentModel;
+import org.apache.tapestry5.model.MutableComponentModel;
+import org.apache.tapestry5.model.ParameterModel;
+import org.apache.tapestry5.runtime.Component;
+import org.apache.tapestry5.services.*;
 import org.easymock.EasyMock;
 import static org.easymock.EasyMock.eq;
 import org.easymock.IAnswer;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/AbstractSelectModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/AbstractSelectModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/AbstractSelectModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/AbstractSelectModel.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.util;
+package org.apache.tapestry5.util;
 
-import org.apache.tapestry.OptionGroupModel;
-import org.apache.tapestry.OptionModel;
-import org.apache.tapestry.SelectModel;
-import org.apache.tapestry.SelectModelVisitor;
+import org.apache.tapestry5.OptionGroupModel;
+import org.apache.tapestry5.OptionModel;
+import org.apache.tapestry5.SelectModel;
+import org.apache.tapestry5.SelectModelVisitor;
 
 import java.util.List;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/DefaultPrimaryKeyEncoder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/DefaultPrimaryKeyEncoder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/DefaultPrimaryKeyEncoder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/DefaultPrimaryKeyEncoder.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.util;
+package org.apache.tapestry5.util;
 
-import org.apache.tapestry.PrimaryKeyEncoder;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.Defense;
+import org.apache.tapestry5.PrimaryKeyEncoder;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.Defense;
 
 import java.io.Serializable;
 import java.util.LinkedHashMap;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumSelectModel.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumSelectModel.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumSelectModel.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumSelectModel.java Tue May 20 11:51:35 2008
@@ -12,15 +12,15 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.util;
+package org.apache.tapestry5.util;
 
-import org.apache.tapestry.OptionGroupModel;
-import org.apache.tapestry.OptionModel;
-import org.apache.tapestry.internal.OptionModelImpl;
-import org.apache.tapestry.internal.TapestryInternalUtils;
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.OptionGroupModel;
+import org.apache.tapestry5.OptionModel;
+import org.apache.tapestry5.internal.OptionModelImpl;
+import org.apache.tapestry5.internal.TapestryInternalUtils;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
 
 import java.io.Serializable;
 import java.util.List;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumValueEncoder.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumValueEncoder.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumValueEncoder.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/EnumValueEncoder.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.util;
+package org.apache.tapestry5.util;
 
-import org.apache.tapestry.ValueEncoder;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ValueEncoder;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
 
 /**
  * A value encoder that can be used for aribrary Enum types. The enum name is stored as the client side value.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/PublicUtilMessages.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/PublicUtilMessages.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/PublicUtilMessages.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/PublicUtilMessages.java Tue May 20 11:51:35 2008
@@ -12,11 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.util;
+package org.apache.tapestry5.util;
 
-import org.apache.tapestry.ioc.Messages;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.internal.util.MessagesImpl;
+import org.apache.tapestry5.ioc.Messages;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.internal.util.MessagesImpl;
 
 import java.util.Collection;
 

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/StringToEnumCoercion.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/StringToEnumCoercion.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/TextStreamResponse.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/TextStreamResponse.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.util;
+package org.apache.tapestry5.util;
 
-import org.apache.tapestry.StreamResponse;
-import static org.apache.tapestry.ioc.internal.util.Defense.notBlank;
-import static org.apache.tapestry.ioc.internal.util.Defense.notNull;
-import org.apache.tapestry.services.Response;
+import org.apache.tapestry5.StreamResponse;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notBlank;
+import static org.apache.tapestry5.ioc.internal.util.Defense.notNull;
+import org.apache.tapestry5.services.Response;
 
 import java.io.ByteArrayInputStream;
 import java.io.IOException;

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/AbstractValidator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/AbstractValidator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Max.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Max.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.validator;
+package org.apache.tapestry5.validator;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.ValidationException;
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.services.FormSupport;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.ValidationException;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.services.FormSupport;
 
 /**
  * Enforces a maximum integer value.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MaxLength.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MaxLength.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MaxLength.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MaxLength.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.validator;
+package org.apache.tapestry5.validator;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.ValidationException;
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.services.FormSupport;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.ValidationException;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.services.FormSupport;
 
 public final class MaxLength extends AbstractValidator<Integer, String>
 {

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Min.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Min.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Min.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Min.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.validator;
+package org.apache.tapestry5.validator;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.ValidationException;
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.services.FormSupport;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.ValidationException;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.services.FormSupport;
 
 /* A vaidator that enforces that a number is greater than some minimum integer value. */
 public class Min extends AbstractValidator<Long, Number>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MinLength.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MinLength.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MinLength.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/MinLength.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.validator;
+package org.apache.tapestry5.validator;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.ValidationException;
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.services.FormSupport;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.ValidationException;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.services.FormSupport;
 
 /**
  * Validates that a string value has a minimum length.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Regexp.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Regexp.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Regexp.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Regexp.java Tue May 20 11:51:35 2008
@@ -12,13 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.validator;
+package org.apache.tapestry5.validator;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.ValidationException;
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.services.FormSupport;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.ValidationException;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.services.FormSupport;
 
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
@@ -50,4 +50,4 @@
         if (!matcher.matches()) throw new ValidationException(buildMessage(formatter, field, constraintValue));
     }
 
-}
\ No newline at end of file
+}

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Required.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Required.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Required.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Required.java Tue May 20 11:51:35 2008
@@ -12,14 +12,14 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.validator;
+package org.apache.tapestry5.validator;
 
-import org.apache.tapestry.Field;
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.ValidationException;
-import org.apache.tapestry.ioc.MessageFormatter;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.services.FormSupport;
+import org.apache.tapestry5.Field;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.ValidationException;
+import org.apache.tapestry5.ioc.MessageFormatter;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.services.FormSupport;
 
 /**
  * A validator that enforces that the value is not null and not the empty string. This validator is not configurable.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/base/BaseStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/base/BaseStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/base/BaseStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/base/BaseStrings.properties Tue May 20 11:51:35 2008
@@ -12,4 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-null-value-in-path=Property '%s' contains a null value in the path.
\ No newline at end of file
+null-value-in-path=Property '%s' contains a null value in the path.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors.properties Tue May 20 11:51:35 2008
@@ -12,4 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-default-banner=You must correct the following errors before you may continue.
\ No newline at end of file
+default-banner=You must correct the following errors before you may continue.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors_it.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors_it.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors_it.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/Errors_it.properties Tue May 20 11:51:35 2008
@@ -12,4 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-default-banner=Per poter proseguire è necessario correggere gli errori seguenti.
\ No newline at end of file
+default-banner=Per poter proseguire è necessario correggere gli errori seguenti.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridColumns.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridColumns.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridColumns.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridColumns.properties Tue May 20 11:51:35 2008
@@ -14,4 +14,4 @@
 
 ascending=[Asc]
 descending=[Desc]
-sortable=[Sortable]
\ No newline at end of file
+sortable=[Sortable]

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridPager.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridPager.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridPager.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/GridPager.properties Tue May 20 11:51:35 2008
@@ -12,4 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-goto-page=Go to page %d
\ No newline at end of file
+goto-page=Go to page %d

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/PropertyEditor.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/PropertyEditor.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/PropertyEditor.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/corelib/components/PropertyEditor.properties Tue May 20 11:51:35 2008
@@ -12,4 +12,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-block-error=Unable to locate a block to edit property '%s' (with data type '%s') of object %s: %s
\ No newline at end of file
+block-error=Unable to locate a block to edit property '%s' (with data type '%s') of object %s: %s

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages.properties Tue May 20 11:51:35 2008
@@ -32,4 +32,4 @@
 
 # The label/alt text for the icon that is displayed next to each field.
 
-icon-label=[Error]
\ No newline at end of file
+icon-label=[Error]

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages_it.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages_it.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages_it.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/ValidationMessages_it.properties Tue May 20 11:51:35 2008
@@ -32,4 +32,4 @@
 
 # The label/alt text for the icon that is displayed next to each field.
 
-icon-label=[Errore]
\ No newline at end of file
+icon-label=[Errore]

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/beaneditor/BeanEditorStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/beaneditor/BeanEditorStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/beaneditor/BeanEditorStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/beaneditor/BeanEditorStrings.properties Tue May 20 11:51:35 2008
@@ -14,4 +14,4 @@
 
 duplicate-property-name=Bean editor model for %s already contains a property model for property '%s'.
 unknown-property=Bean editor model for %s does not contain a property named '%s'.  Available properties: %s.
-unknown-property-id=Bean editor model for %s does not contain a property with id '%s'.  Available property ids: %s.
\ No newline at end of file
+unknown-property-id=Bean editor model for %s does not contain a property with id '%s'.  Available property ids: %s.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/model/ModelStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/model/ModelStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/model/ModelStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/model/ModelStrings.properties Tue May 20 11:51:35 2008
@@ -16,4 +16,4 @@
 duplicate-parameter-value=A value for parameter '%s' of embedded component %s (of component class %s) has already been provided.
 duplicate-component-id=Embedded component '%s' has already been defined for component class %s.
 duplicate-mixin=Mixin %s (for component %s) has already been defined.
-missing-persistent-field=No field persistence strategy has been defined for field '%s'.
\ No newline at end of file
+missing-persistent-field=No field persistence strategy has been defined for field '%s'.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/transform/TransformStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/transform/TransformStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/transform/TransformStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/transform/TransformStrings.properties Tue May 20 11:51:35 2008
@@ -15,4 +15,4 @@
 field-injection-error=Error obtaining injected value for field %s.%s: %s
 component-not-assignable-to-field=Component %s is not assignable to field %s (of type %s).
 cached-no-return-value=@Cached may only be used with methods that return values: %s
-cached-no-parameters=@Cached cannot be used with methods that accept parameters: %s
\ No newline at end of file
+cached-no-parameters=@Cached cannot be used with methods that accept parameters: %s

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/util/UtilStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/util/UtilStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/util/UtilStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/internal/util/UtilStrings.properties Tue May 20 11:51:35 2008
@@ -13,4 +13,4 @@
 # limitations under the License.
 
 no-return-value-accepted=Event '%s' from %s received an event handler method return value of %s. \
-  This type of event does not support return values from event handler methods.
\ No newline at end of file
+  This type of event does not support return values from event handler methods.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/util/PublicUtilStrings.properties
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/util/PublicUtilStrings.properties?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/util/PublicUtilStrings.properties (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/resources/org/apache/tapestry5/util/PublicUtilStrings.properties Tue May 20 11:51:35 2008
@@ -14,4 +14,4 @@
 
 duplicate-key=Key %s may not be added with value %s, as an existing value, %s, is already present.
 missing-value=Key for value %s not found. Available values: %s
-missing-enum-value=Input '%s' does not identify a value from enumerated type %s. Available values: %s.
\ No newline at end of file
+missing-enum-value=Input '%s' does not identify a value from enumerated type %s. Available values: %s.
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformConstants.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformConstants.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.MarkupWriter;
-import org.apache.tapestry.runtime.ComponentEvent;
-import org.apache.tapestry.runtime.Event;
+import org.apache.tapestry5.MarkupWriter;
+import org.apache.tapestry5.runtime.ComponentEvent;
+import org.apache.tapestry5.runtime.Event;
 
 import java.lang.reflect.Modifier;
 
 /**
  * Constants used by implementations of {@link org.apache.tapestry.services.ComponentClassTransformWorker}.
  */
 public final class TransformConstants
 {
@@ -31,94 +31,94 @@
             Event.class.getName() };
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#dispatchComponentEvent(org.apache.tapestry.runtime.ComponentEvent)}.
      *
-     * @see org.apache.tapestry.annotation.OnEvent
+     * @see org.apache.tapestry5.annotations.OnEvent
      */
     public static final TransformMethodSignature DISPATCH_COMPONENT_EVENT = new TransformMethodSignature(
             Modifier.PUBLIC, "boolean", "dispatchComponentEvent", new String[] { ComponentEvent.class.getName() },
             null);
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.PageLifecycleListener#containingPageDidLoad()}.
      */
     public static final TransformMethodSignature CONTAINING_PAGE_DID_LOAD_SIGNATURE = new TransformMethodSignature(
             "containingPageDidLoad");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#postRenderCleanup()}.
      */
     public static final TransformMethodSignature POST_RENDER_CLEANUP_SIGNATURE = new TransformMethodSignature(
             "postRenderCleanup");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.PageLifecycleListener#containingPageDidDetach()}.
      */
     public static final TransformMethodSignature CONTAINING_PAGE_DID_DETACH_SIGNATURE = new TransformMethodSignature(
             "containingPageDidDetach");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.PageLifecycleListener#containingPageDidAttach()}.
      */
     public static final TransformMethodSignature CONTAINING_PAGE_DID_ATTACH_SIGNATURE = new TransformMethodSignature(
             "containingPageDidAttach");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#setupRender(MarkupWriter, Event)}.
      *
-     * @see org.apache.tapestry.annotation.SetupRender
+     * @see org.apache.tapestry5.annotations.SetupRender
      */
     public static final TransformMethodSignature SETUP_RENDER_SIGNATURE = renderPhaseSignature("setupRender");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#beginRender(MarkupWriter, Event)}.
      *
-     * @see org.apache.tapestry.annotation.BeginRender
+     * @see org.apache.tapestry5.annotations.BeginRender
      */
     public static final TransformMethodSignature BEGIN_RENDER_SIGNATURE = renderPhaseSignature("beginRender");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#beforeRenderTemplate(MarkupWriter, Event)}.
      *
-     * @see org.apache.tapestry.annotation.BeforeRenderTemplate
+     * @see org.apache.tapestry5.annotations.BeforeRenderTemplate
      */
     public static final TransformMethodSignature BEFORE_RENDER_TEMPLATE_SIGNATURE = renderPhaseSignature(
             "beforeRenderTemplate");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#afterRenderTemplate(MarkupWriter, Event)}.
      *
-     * @see org.apache.tapestry.annotation.BeforeRenderTemplate
+     * @see org.apache.tapestry5.annotations.BeforeRenderTemplate
      */
     public static final TransformMethodSignature AFTER_RENDER_TEMPLATE_SIGNATURE = renderPhaseSignature(
             "afterRenderTemplate");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#beforeRenderBody(MarkupWriter, Event)}.
      *
-     * @see org.apache.tapestry.annotation.BeforeRenderBody
+     * @see org.apache.tapestry5.annotations.BeforeRenderBody
      */
     public static final TransformMethodSignature BEFORE_RENDER_BODY_SIGNATURE = renderPhaseSignature(
             "beforeRenderBody");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#afterRenderBody(MarkupWriter, Event)}.
      *
-     * @see org.apache.tapestry.annotation.AfterRenderBody
+     * @see org.apache.tapestry5.annotations.AfterRenderBody
      */
     public static final TransformMethodSignature AFTER_RENDER_BODY_SIGNATURE = renderPhaseSignature("afterRenderBody");
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#afterRender(MarkupWriter, Event)}
+     * Signature for {@link org.apache.tapestry5.runtime.Component#afterRender(MarkupWriter, Event)}
      *
-     * @see org.apache.tapestry.annotation.AfterRender
+     * @see org.apache.tapestry5.annotations.AfterRender
      */
     public static final TransformMethodSignature AFTER_RENDER_SIGNATURE = renderPhaseSignature("afterRender");
 
     /**
      * Signature for {@link org.apache.tapestry.runtime.Component#cleanupRender(MarkupWriter, Event)}.
      *
-     * @see org.apache.tapestry.annotation.CleanupRender
+     * @see org.apache.tapestry5.annotations.CleanupRender
      */
     public static final TransformMethodSignature CLEANUP_RENDER_SIGNATURE = renderPhaseSignature("cleanupRender");
 
@@ -12,16 +12,16 @@
 
 /**
- * Constants used by implementations of {@link org.apache.tapestry.services.ComponentClassTransformWorker}.
+ * Constants used by implementations of {@link org.apache.tapestry5.services.ComponentClassTransformWorker}.
  */
 public final class TransformConstants
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#dispatchComponentEvent(org.apache.tapestry.runtime.ComponentEvent)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#dispatchComponentEvent(org.apache.tapestry5.runtime.ComponentEvent)}.
      *
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.PageLifecycleListener#containingPageDidLoad()}.
+     * Signature for {@link org.apache.tapestry5.runtime.PageLifecycleListener#containingPageDidLoad()}.
      */
     public static final TransformMethodSignature CONTAINING_PAGE_DID_LOAD_SIGNATURE = new TransformMethodSignature(
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#postRenderCleanup()}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#postRenderCleanup()}.
      */
     public static final TransformMethodSignature POST_RENDER_CLEANUP_SIGNATURE = new TransformMethodSignature(
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.PageLifecycleListener#containingPageDidDetach()}.
+     * Signature for {@link org.apache.tapestry5.runtime.PageLifecycleListener#containingPageDidDetach()}.
      */
     public static final TransformMethodSignature CONTAINING_PAGE_DID_DETACH_SIGNATURE = new TransformMethodSignature(
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.PageLifecycleListener#containingPageDidAttach()}.
+     * Signature for {@link org.apache.tapestry5.runtime.PageLifecycleListener#containingPageDidAttach()}.
      */
     public static final TransformMethodSignature CONTAINING_PAGE_DID_ATTACH_SIGNATURE = new TransformMethodSignature(
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#setupRender(MarkupWriter, Event)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#setupRender(MarkupWriter, Event)}.
      *
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#beginRender(MarkupWriter, Event)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#beginRender(MarkupWriter, Event)}.
      *
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#beforeRenderTemplate(MarkupWriter, Event)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#beforeRenderTemplate(MarkupWriter, Event)}.
      *
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#afterRenderTemplate(MarkupWriter, Event)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#afterRenderTemplate(MarkupWriter, Event)}.
      *
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#beforeRenderBody(MarkupWriter, Event)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#beforeRenderBody(MarkupWriter, Event)}.
      *
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#afterRenderBody(MarkupWriter, Event)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#afterRenderBody(MarkupWriter, Event)}.
      *
@@ -31,94 +31,94 @@
 
     /**
-     * Signature for {@link org.apache.tapestry.runtime.Component#cleanupRender(MarkupWriter, Event)}.
+     * Signature for {@link org.apache.tapestry5.runtime.Component#cleanupRender(MarkupWriter, Event)}.
      *

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformMethodSignature.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TransformMethodSignature.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TranslatorSource.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/TranslatorSource.java Tue May 20 11:51:35 2008
@@ -12,9 +12,9 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.Translator;
+import org.apache.tapestry5.Translator;
 
 /**
  * A source for {@link Translator}s, either by name.
@@ -32,7 +32,7 @@
 
     /**
      * Finds a {@link Translator} that is appropriate to the given type, which is usually obtained via {@link
      * org.apache.tapestry.Binding#getBindingType()}. Performs an inheritanced-based search for the best match.
      *
      * @param valueType the type of value for which a default translator is needed
      * @return the matching translator, or null if no match can be found
@@ -41,7 +41,7 @@
 
     /**
      * Finds a {@link Translator} that is appropriate to the given type, which is usually obtained via {@link
      * org.apache.tapestry.Binding#getBindingType()}. Performs an inheritanced-based search for the best match.
      *
      * @param valueType the type of value for which a default translator is needed
      * @return the matching translator
@@ -32,7 +32,7 @@
     /**
      * Finds a {@link Translator} that is appropriate to the given type, which is usually obtained via {@link
-     * org.apache.tapestry.Binding#getBindingType()}. Performs an inheritanced-based search for the best match.
+     * org.apache.tapestry5.Binding#getBindingType()}. Performs an inheritanced-based search for the best match.
      *
      * @param valueType the type of value for which a default translator is needed
@@ -41,7 +41,7 @@
     /**
      * Finds a {@link Translator} that is appropriate to the given type, which is usually obtained via {@link
-     * org.apache.tapestry.Binding#getBindingType()}. Performs an inheritanced-based search for the best match.
+     * org.apache.tapestry5.Binding#getBindingType()}. Performs an inheritanced-based search for the best match.
      *
      * @param valueType the type of value for which a default translator is needed

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationConstraintGenerator.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationConstraintGenerator.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationConstraintGenerator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationConstraintGenerator.java Tue May 20 11:51:35 2008
@@ -12,25 +12,25 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.services;
+package org.apache.tapestry5.services;
 
-import org.apache.tapestry.FieldValidator;
-import org.apache.tapestry.ioc.AnnotationProvider;
+import org.apache.tapestry5.FieldValidator;
+import org.apache.tapestry5.ioc.AnnotationProvider;
 
 import java.util.List;
 
 /**
  * Invoked to generate a list of validation constraint strings for a property. This typically involves scanning the
  * property for annotations or naming conventions that confer the desired validation. The constraint strings are
  * ultimately handed to {@link FieldValidatorSource#createValidator(org.apache.tapestry.Field, String, String, String,
  * org.apache.tapestry.ioc.Messages, java.util.Locale)}.
  */
 public interface ValidationConstraintGenerator
 {
     /**
      * For a given property, identify all the approprite validation constraints. Each returned value is the name of a
      * validator (i.e., "required") or a validator name and configuration (i.e., "minlength=5"). These contraints are
      * exactly the individual terms in a {@link FieldValidatorSource#createValidators(org.apache.tapestry.Field, String)
      * validate specification}. These will ultimately be used to create {@link FieldValidator}s for the field that edits
      * the property.
      *
@@ -12,25 +12,25 @@
  * Invoked to generate a list of validation constraint strings for a property. This typically involves scanning the
  * property for annotations or naming conventions that confer the desired validation. The constraint strings are
- * ultimately handed to {@link FieldValidatorSource#createValidator(org.apache.tapestry.Field, String, String, String,
- * org.apache.tapestry.ioc.Messages, java.util.Locale)}.
+ * ultimately handed to {@link FieldValidatorSource#createValidator(org.apache.tapestry5.Field, String, String, String,
+ * org.apache.tapestry5.ioc.Messages, java.util.Locale)}.
  */
 public interface ValidationConstraintGenerator
@@ -12,25 +12,25 @@
      * For a given property, identify all the approprite validation constraints. Each returned value is the name of a
      * validator (i.e., "required") or a validator name and configuration (i.e., "minlength=5"). These contraints are
-     * exactly the individual terms in a {@link FieldValidatorSource#createValidators(org.apache.tapestry.Field, String)
+     * exactly the individual terms in a {@link FieldValidatorSource#createValidators(org.apache.tapestry5.Field, String)
      * validate specification}. These will ultimately be used to create {@link FieldValidator}s for the field that edits
      * the property.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationMessagesSource.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/services/ValidationMessagesSource.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/StringToEnumCoercion.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/StringToEnumCoercion.java Tue May 20 11:51:35 2008
@@ -12,16 +12,16 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.util;
+package org.apache.tapestry5.util;
 
-import org.apache.tapestry.ioc.internal.util.CollectionFactory;
-import org.apache.tapestry.ioc.internal.util.InternalUtils;
-import org.apache.tapestry.ioc.services.Coercion;
+import org.apache.tapestry5.ioc.internal.util.CollectionFactory;
+import org.apache.tapestry5.ioc.internal.util.InternalUtils;
+import org.apache.tapestry5.ioc.services.Coercion;
 
 import java.util.Map;
 
 /**
  * A {@link org.apache.tapestry.ioc.services.Coercion} for converting strings into an instance of a particular
  * enumerated type. The {@link Enum#name() name} is used as the key to identify the enum instance, in a case-insensitive
  * fashion.
  *
@@ -12,16 +12,16 @@
 
 /**
- * A {@link org.apache.tapestry.ioc.services.Coercion} for converting strings into an instance of a particular
+ * A {@link org.apache.tapestry5.ioc.services.Coercion} for converting strings into an instance of a particular
  * enumerated type. The {@link Enum#name() name} is used as the key to identify the enum instance, in a case-insensitive
  * fashion.

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/TextStreamResponse.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/util/TextStreamResponse.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================
--- tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/AbstractValidator.java (original)
+++ tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/AbstractValidator.java Tue May 20 11:51:35 2008
@@ -12,12 +12,12 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-package org.apache.tapestry.validator;
+package org.apache.tapestry5.validator;
 
-import org.apache.tapestry.Validator;
+import org.apache.tapestry5.Validator;
 
 /**
  * Base class for constructing a {@link org.apache.tapestry.Validator}.
  */
 public abstract class AbstractValidator<C, T> implements Validator<C, T>
 {
@@ -12,12 +12,12 @@
 
 /**
- * Base class for constructing a {@link org.apache.tapestry.Validator}.
+ * Base class for constructing a {@link org.apache.tapestry5.Validator}.
  */
 public abstract class AbstractValidator<C, T> implements Validator<C, T>

Modified: tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Max.java
URL: http://svn.apache.org/viewvc/tapestry/tapestry5/branches/hlship-20080520/tapestry-core/src/main/java/org/apache/tapestry5/validator/Max.java?rev=658390&r1=658389&r2=658390&view=diff
==============================================================================